package com.iconplus.smartproc.repository;

import com.iconplus.smartproc.model.entity.Drp;
import com.iconplus.smartproc.model.projection.DrpApprovalView;
import com.iconplus.smartproc.model.projection.DrpView;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.sql.Timestamp;
import java.util.List;
import java.util.Optional;

@Repository
public interface DrpRepository extends JpaRepository<Drp, Long> {

    Optional<Drp> findByIdAndIsDeleteFalse(Long id);

    Optional<Drp> findByTahunAndIsDeleteFalse(Integer tahun);

    @Query(value = "SELECT d.id as id, " +
            "d.tahun as tahun, " +
            "d.approveStatus as approveStatus, " +
            "d.approveDate as approveDate, " +
            "d.isActive as isActive, " +
            "d.isDelete as isDelete " +
            "FROM Drp d " +
            "WHERE d.isDelete = false " +
//            "AND (:approveDate = '' or DATE(d.approveDate) = DATE(approveDate)) " +
            "ORDER BY d.id")
    Page<DrpView> findByIsDeleteFalse(Timestamp approveDate,
                                      Pageable pageable);


    @Query(value = "SELECT d.id as id, " +
            "d.tahun as tahun, " +
            "d.approveStatus as approveStatus, " +
            "da.approverVpDate as approverVpDate, " +
            "da.approverKomite1Date as approverKomite1Date, " +
            "da.approverKomite2Date as approverKomite2Date, " +
            "da.approverKomite3Date as approverKomite3Date, " +
            "da.approverKomite4Date as approverKomite4Date, " +
            "da.approverDirekturDate as approverDirekturDate " +
            "FROM Drp d " +
            "JOIN DrpApproval da ON da.drpId = d.id " +
            "WHERE d.isDelete = false")
    Page<DrpApprovalView> getListApprovalDrp(Pageable pageable);
}
